@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -123,7 +123,7 @@ static int stress_wait_until_reaped(
 				break;
 			}
 		}
-		shim_sched_yield();
+		(void)shim_sched_yield();
 		if (count > 10)
 			(void)sleep(1);
 	}
