@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,7 +34,7 @@ static const stress_help_t help[] = {
 };
 
 static const stress_opt_t opts[] = {
-	{ OPT_copy_file_bytes, "copy-file-bytes", TYPE_ID_UINT64_BYTES, MIN_COPY_FILE_BYTES, MAX_COPY_FILE_BYTES, NULL },
+	{ OPT_copy_file_bytes, "copy-file-bytes", TYPE_ID_UINT64_BYTES_FS, MIN_COPY_FILE_BYTES, MAX_COPY_FILE_BYTES, NULL },
 	END_OPT,
 };
 
@@ -202,16 +202,16 @@ static int stress_copy_file(stress_args_t *args)
 #if defined(HAVE_PATHCONF)
 	/* Exercise some pathconf options */
 #if defined(_PC_REC_INCR_XFER_SIZE)
-	VOID_RET(long, pathconf(tmp, _PC_REC_INCR_XFER_SIZE));
+	VOID_RET(long int, pathconf(tmp, _PC_REC_INCR_XFER_SIZE));
 #endif
 #if defined(_PC_REC_MAX_XFER_SIZE)
-	VOID_RET(long, pathconf(tmp, _PC_REC_MAX_XFER_SIZE));
+	VOID_RET(long int, pathconf(tmp, _PC_REC_MAX_XFER_SIZE));
 #endif
 #if defined(_PC_REC_MIN_XFER_SIZE)
-	VOID_RET(long, pathconf(tmp, _PC_REC_MIN_XFER_SIZE));
+	VOID_RET(long int, pathconf(tmp, _PC_REC_MIN_XFER_SIZE));
 #endif
 #if defined(_PC_REC_XFER_ALIGN)
-	VOID_RET(long, pathconf(tmp, _PC_REC_XFER_ALIGN));
+	VOID_RET(long int, pathconf(tmp, _PC_REC_XFER_ALIGN));
 #endif
 #endif
 	(void)shim_unlink(tmp);
@@ -319,7 +319,7 @@ tidy_dir:
 	return rc;
 }
 
-stressor_info_t stress_copy_file_info = {
+const stressor_info_t stress_copy_file_info = {
 	.stressor = stress_copy_file,
 	.class = CLASS_FILESYSTEM | CLASS_OS,
 	.opts = opts,
@@ -327,7 +327,7 @@ stressor_info_t stress_copy_file_info = {
 	.help = help
 };
 #else
-stressor_info_t stress_copy_file_info = {
+const stressor_info_t stress_copy_file_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_FILESYSTEM | CLASS_OS,
 	.opts = opts,
