@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2016-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -466,7 +466,7 @@ finish:
 	return rc;
 }
 
-stressor_info_t stress_dccp_info = {
+const stressor_info_t stress_dccp_info = {
 	.stressor = stress_dccp,
 	.class = CLASS_NETWORK | CLASS_OS,
 	.opts = opts,
@@ -474,7 +474,7 @@ stressor_info_t stress_dccp_info = {
 	.help = help
 };
 #else
-stressor_info_t stress_dccp_info = {
+const stressor_info_t stress_dccp_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_NETWORK | CLASS_OS,
 	.opts = opts,
