@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -437,10 +437,7 @@ static int stress_expmath(stress_args_t *args)
 
 	(void)stress_get_setting("expmath-method", &expmath_method);
 
-	for (i = 0; i < NUM_EXPMATH_METHODS; i++) {
-		stress_expmath_metrics[i].duration = 0.0;
-		stress_expmath_metrics[i].count = 0.0;
-	}
+	stress_zero_metrics(stress_expmath_metrics, NUM_EXPMATH_METHODS);
 
 	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
