@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -701,7 +701,7 @@ static void stress_fd_race_filename_dir(const char *dirname, stress_fd_race_file
 			continue;
 
 		for (len = (ssize_t)strlen(de->d_name) - 1; len > 1; len--) {
-			if (!isdigit((int)de->d_name[len]))
+			if (!isdigit((unsigned char)de->d_name[len]))
 				break;
 		}
 		/* ignore numbered files such as /dev/tty1 upwards */
