@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King
+ * Copyright (C) 2022-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -255,13 +255,15 @@ static int stress_flushcache_child(stress_args_t *args, void *ctxt)
 			args->name, context->d_size);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(context->d_addr, context->d_size, "d-cache");
 
 	if (context->i_addr)
 		(void)stress_flushcache_nohugepage(context->i_addr, context->i_size);
 	(void)stress_flushcache_nohugepage(context->d_addr, context->d_size);
 
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
 		if (context->i_addr)
@@ -304,6 +306,7 @@ static int stress_flushcache(stress_args_t *args)
 			args->name, page_size);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(context.i_addr, page_size, "i-cache");
 	context.icache_func = (stress_ret_func_t)context.i_addr;
 	context.i_size = page_size;
 
@@ -325,14 +328,14 @@ static int stress_flushcache(stress_args_t *args)
 	return ret;
 }
 
-stressor_info_t stress_flushcache_info = {
+const stressor_info_t stress_flushcache_info = {
 	.stressor = stress_flushcache,
 	.class = CLASS_CPU_CACHE,
 	.supported = stress_asm_ret_supported,
 	.help = help
 };
 #else
-stressor_info_t stress_flushcache_info = {
+const stressor_info_t stress_flushcache_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_CPU_CACHE,
 	.supported = stress_asm_ret_supported,
