@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,6 +19,13 @@
  */
 #include "stress-ng.h"
 #include "core-arch.h"
+#include "core-numa.h"
+
+#if defined(HAVE_LINUX_MEMPOLICY_H) &&  \
+    defined(__NR_mbind)
+#include <linux/mempolicy.h>
+#define HAVE_NUMA_LOCKBUS	(1)
+#endif
 
 static const stress_help_t help[] = {
 	{ NULL,	"lockbus N",	 	"start N workers locking a memory increment" },
@@ -155,6 +162,9 @@ static int stress_lockbus(stress_args_t *args)
 	if (stress_sighandler(args->name, SIGBUS, stress_sigbus_handler, NULL) < 0)
 		return EXIT_FAILURE;
 #endif
+#if defined(HAVE_NUMA_LOCKBUS)
+	NOCLOBBER stress_numa_mask_t *numa_mask;
+#endif
 
 	buffer = (uint32_t*)stress_mmap_populate(NULL, BUFFER_SIZE,
 			PROT_READ | PROT_WRITE, MAP_ANONYMOUS | MAP_SHARED, -1, 0);
@@ -179,6 +189,12 @@ static int stress_lockbus(stress_args_t *args)
 		goto done;
 #endif
 
+#if defined(HAVE_NUMA_LOCKBUS)
+	numa_mask = stress_numa_mask_alloc();
+	if (numa_mask)
+		stress_numa_randomize_pages(numa_mask, (void *)buffer, args->page_size, BUFFER_SIZE);
+#endif
+
 	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
@@ -246,19 +262,22 @@ done:
 	stress_metrics_set(args, 0, "nanosecs per memory lock operation",
 		rate * STRESS_DBL_NANOSECOND, STRESS_METRIC_HARMONIC_MEAN);
 
+#if defined(HAVE_NUMA_LOCKBUS)
+	stress_numa_mask_free(numa_mask);
+#endif
 	(void)munmap((void *)buffer, BUFFER_SIZE);
 
 	return EXIT_SUCCESS;
 }
 
-stressor_info_t stress_lockbus_info = {
+const stressor_info_t stress_lockbus_info = {
 	.stressor = stress_lockbus,
 	.class = CLASS_CPU_CACHE | CLASS_MEMORY,
 	.opts = opts,
 	.help = help
 };
 #else
-stressor_info_t stress_lockbus_info = {
+const stressor_info_t stress_lockbus_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_CPU_CACHE | CLASS_MEMORY,
 	.opts = opts,
