@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -74,8 +74,9 @@ static int OPTIMIZE1 stress_longjmp(stress_args_t *args)
 	bufchk.check0 = check0;
 	bufchk.check1 = check1;
 
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	ret = setjmp(bufchk.buf);
 	if (ret) {
@@ -128,7 +129,7 @@ static int OPTIMIZE1 stress_longjmp(stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_longjmp_info = {
+const stressor_info_t stress_longjmp_info = {
 	.stressor = stress_longjmp,
 	.class = CLASS_CPU,
 	.verify = VERIFY_ALWAYS,
