@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,8 +22,21 @@
 #include "core-builtin.h"
 #include "core-madvise.h"
 #include "core-target-clones.h"
+#include "core-numa.h"
 #include "core-nt-store.h"
 
+#include <time.h>
+
+#if defined(HAVE_LINUX_MEMPOLICY_H) &&  \
+    defined(__NR_mbind)
+#include <linux/mempolicy.h>
+#define HAVE_MISALIGNED_NUMA	(1)
+#endif
+
+#define BITS_PER_BYTE           (8)
+#define NUMA_LONG_BITS          (sizeof(unsigned long int) * BITS_PER_BYTE)
+
+
 #define MISALIGN_LOOPS		(64)
 
 /* Disable atomic ops for SH4 as this breaks gcc on Debian sid */
@@ -1181,7 +1194,10 @@ static int stress_misaligned(stress_args_t *args)
 	const clockid_t clockid = CLOCK_REALTIME;
 #endif
 #endif
-
+#if defined(HAVE_MISALIGNED_NUMA)
+	stress_numa_mask_t *numa_mask;
+	int numa_loop;
+#endif
 	(void)stress_get_setting("misaligned-method", &misaligned_method);
 
 	if (stress_sighandler(args->name, SIGBUS, stress_misaligned_handler, NULL) < 0)
@@ -1205,8 +1221,15 @@ static int stress_misaligned(stress_args_t *args)
 			args->name, errno, strerror(errno));
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(buffer, buffer_size, "misaligned-data");
 	(void)stress_madvise_mergeable(buffer, buffer_size);
 
+#if defined(HAVE_MISALIGNED_NUMA)
+	numa_mask = stress_numa_mask_alloc();
+	if (numa_mask)
+		stress_numa_randomize_pages(numa_mask, buffer, page_size, buffer_size);
+#endif
+
 #if defined(HAVE_TIMER_FUNCTIONALITY)
 	(void)shim_memset(&sev, 0, sizeof(sev));
 	sev.sigev_notify = SIGEV_SIGNAL;
@@ -1244,6 +1267,9 @@ static int stress_misaligned(stress_args_t *args)
 		}
 	}
 
+#if defined(HAVE_MISALIGNED_NUMA)
+	numa_loop = 0;
+#endif
 	rc = EXIT_SUCCESS;
 	do {
 		if (stress_time_now() > args->time_end)
@@ -1257,6 +1283,20 @@ static int stress_misaligned(stress_args_t *args)
 #endif
 		method->func(args, (uintptr_t)buffer, page_size, &succeeded);
 		method->exercised = true;
+
+#if defined(HAVE_MISALIGNED_NUMA)
+		/*
+		 *  On NUMA systems with > 1 node, randomize the
+		 *  NUMA node binding of pages in the buffer
+		 */
+		if (numa_mask && (numa_mask->nodes > 1)) {
+			numa_loop++;
+			if (numa_loop > 1024) {
+				numa_loop = 0;
+				stress_numa_randomize_pages(numa_mask, buffer, page_size, buffer_size);
+			}
+		}
+#endif
 		stress_bogo_inc(args);
 	} while (stress_continue(args));
 
@@ -1276,6 +1316,9 @@ static int stress_misaligned(stress_args_t *args)
 
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
+#if defined(HAVE_MISALIGNED_NUMA)
+	stress_numa_mask_free(numa_mask);
+#endif
 	(void)munmap((void *)buffer, buffer_size);
 
 	if (!succeeded && (rc == EXIT_SUCCESS))
