@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -241,8 +241,10 @@ static int stress_mknod(stress_args_t *args)
 		args->pid, args->instance);
 	dir_fd = open(pathname, O_DIRECTORY | O_RDONLY);
 #endif
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
 		register uint64_t i;
@@ -256,7 +258,7 @@ static int stress_mknod(stress_args_t *args)
 		for (i = 0; stress_continue(args) && (i < n); i++) {
 			char path[PATH_MAX];
 			register const uint64_t gray_code = (i >> 1) ^ i;
-			register size_t j = stress_mwc32modn(num_nodes);
+			register const size_t j = stress_mwc32modn(num_nodes);
 
 			(void)stress_temp_filename_args(args,
 				path, sizeof(path), gray_code);
@@ -284,14 +286,14 @@ static int stress_mknod(stress_args_t *args)
 	return EXIT_SUCCESS;
 }
 
-stressor_info_t stress_mknod_info = {
+const stressor_info_t stress_mknod_info = {
 	.stressor = stress_mknod,
 	.class = CLASS_FILESYSTEM | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
-stressor_info_t stress_mknod_info = {
+const stressor_info_t stress_mknod_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_FILESYSTEM | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
