@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -178,7 +178,7 @@ static size_t stress_mlock_max_lockable(void)
 
 #if defined(_SC_MEMLOCK)
 	{
-		const long lockmax = sysconf(_SC_MEMLOCK);
+		const long int lockmax = sysconf(_SC_MEMLOCK);
 
 		sysconf_max = (lockmax > 0) ? (size_t)lockmax : MLOCK_MAX;
 	}
@@ -295,7 +295,7 @@ static int stress_mlock_child(stress_args_t *args, void *context)
 	size_t i, n;
 	uint8_t **mappings;
 	const size_t page_size = args->page_size;
-	const size_t max = stress_mlock_max_lockable();
+	size_t max = stress_mlock_max_lockable(), mappings_max;
 	size_t mappings_len = max * sizeof(*mappings);
 	size_t shmall, freemem, totalmem, freeswap, totalswap;
 	double mlock_duration = 0.0, mlock_count = 0.0;
@@ -345,14 +345,21 @@ static int stress_mlock_child(stress_args_t *args, void *context)
 		}
 		mappings_len = mappings_len >> 1;
 		/* mmap failed, yield a bit before retry */
-		shim_sched_yield();
+		(void)shim_sched_yield();
 	}
 	if (mappings == MAP_FAILED) {
 		pr_inf_skip("%s: cannot mmap mappings table: errno=%d (%s), skipping stressor\n",
 			args->name, errno, strerror(errno));
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(mappings, mappings_len, "mmap-mappings");
 
+	mappings_max = mappings_len / sizeof(*mappings);
+	if (max > mappings_max)
+		max = mappings_max;
+
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
@@ -431,7 +438,7 @@ static int stress_mlock_child(stress_args_t *args, void *context)
 
 		for (i = 0; i < n; i++) {
 			intptr_t addr = (intptr_t)mappings[i];
-			intptr_t mlocked = addr & 1;
+			const intptr_t mlocked = addr & 1;
 
 			addr &= ~(intptr_t)1;
 
@@ -489,11 +496,11 @@ static int stress_mlock_child(stress_args_t *args, void *context)
 
 	rate = (mlock_count > 0.0) ? mlock_duration / mlock_count : 0.0;
 	stress_metrics_set(args, 0, "nanosecs per mlock call",
-		rate * STRESS_DBL_NANOSECOND, STRESS_HARMONIC_MEAN);
+		rate * STRESS_DBL_NANOSECOND, STRESS_METRIC_HARMONIC_MEAN);
 	if (munlock_count > 0.0) {
 		rate =  munlock_duration / munlock_count;
 		stress_metrics_set(args, 1, "nanosecs per munlock call",
-			rate * STRESS_DBL_NANOSECOND, STRESS_HARMONIC_MEAN);
+			rate * STRESS_DBL_NANOSECOND, STRESS_METRIC_HARMONIC_MEAN);
 	}
 
 	(void)munmap((void *)mappings, mappings_len);
@@ -510,14 +517,14 @@ static int stress_mlock(stress_args_t *args)
 	return stress_oomable_child(args, NULL, stress_mlock_child, STRESS_OOMABLE_NORMAL);
 }
 
-stressor_info_t stress_mlock_info = {
+const stressor_info_t stress_mlock_info = {
 	.stressor = stress_mlock,
 	.class = CLASS_VM | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
-stressor_info_t stress_mlock_info = {
+const stressor_info_t stress_mlock_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_VM | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
