@@ -1,6 +1,6 @@
 /*
  * Copyright (C)      2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -45,7 +45,7 @@ static const stress_help_t help[] = {
 static inline size_t PURE stress_munmap_log2(size_t n)
 {
 #if defined(HAVE_BUILTIN_CLZLL)
-	long long lln = (long long)n;
+	long long int lln = (long long int)n;
 
 	return (8 * sizeof(lln)) - __builtin_clzll(lln) - 1;
 #else
