@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -318,7 +318,7 @@ static int stress_physpage(stress_args_t *args)
 	return success ? EXIT_SUCCESS : EXIT_FAILURE;
 }
 
-stressor_info_t stress_physpage_info = {
+const stressor_info_t stress_physpage_info = {
 	.stressor = stress_physpage,
 	.supported = stress_physpage_supported,
 	.opts = opts,
@@ -327,7 +327,7 @@ stressor_info_t stress_physpage_info = {
 	.help = help
 };
 #else
-stressor_info_t stress_physpage_info = {
+const stressor_info_t stress_physpage_info = {
 	.stressor = stress_unimplemented,
 	.opts = opts,
 	.class = CLASS_VM,
