@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -250,12 +250,14 @@ static int stress_rmap(stress_args_t *args)
 			goto cleanup;
 
 		mappings[i] =
-			(uint32_t *)mmap(0, MAPPING_PAGES * page_size, PROT_READ | PROT_WRITE,
+			(uint32_t *)mmap(NULL, MAPPING_PAGES * page_size, PROT_READ | PROT_WRITE,
 				MAP_SHARED, fd, offset);
 		/* Squeeze at least a page in between each mapping */
 		paddings[i] =
-			(uint32_t *)mmap(0, page_size, PROT_READ | PROT_WRITE,
+			(uint32_t *)mmap(NULL, page_size, PROT_READ | PROT_WRITE,
 				MAP_SHARED | MAP_ANONYMOUS, -1, 0);
+		if (paddings[i] != MAP_FAILED)
+			stress_set_vma_anon_name(paddings[i], page_size, "mmap-padding");
 	}
 
 	/*
