@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,6 +41,7 @@ static const stress_opt_t opts[] = {
      !defined(__OpenBSD__) &&						\
      !defined(__minix__) &&						\
      !defined(__APPLE__) &&						\
+     !defined(__HAIKU__) &&						\
      !defined(__serenity__)
 
 static int stress_schedpolicy(stress_args_t *args)
@@ -109,7 +110,7 @@ static int stress_schedpolicy(stress_args_t *args)
 		if (!stress_continue(args))
 			break;
 
-		shim_sched_yield();
+		(void)shim_sched_yield();
 		errno = 0;
 
 		switch (new_policy) {
@@ -144,6 +145,9 @@ static int stress_schedpolicy(stress_args_t *args)
 #if defined(SCHED_BATCH)
 		case SCHED_BATCH:
 #endif
+#if defined(SCHED_EXT)
+		case SCHED_EXT:
+#endif
 #if defined(SCHED_OTHER)
 		case SCHED_OTHER:
 #endif
@@ -234,9 +238,10 @@ case_sched_fifo:
 			} else if (ret != stress_sched_types[policy].sched) {
 				pr_fail("%s: sched_getscheduler "
 					"failed: PID %jd has policy %d (%s) "
-					"but function returned %d instead\n",
+					"but function returned %d (%s) instead\n",
 					args->name, (intmax_t)pid, new_policy,
-					new_policy_name, ret);
+					new_policy_name, ret,
+					stress_get_sched_name(ret));
 				rc = EXIT_FAILURE;
 				break;
 			}
@@ -308,7 +313,7 @@ case_sched_fifo:
 			const size_t large_attr_size = args->page_size + 16;
 			char *large_attr;
 
-			large_attr = calloc(large_attr_size, sizeof(*large_attr));
+			large_attr = (char *)calloc(large_attr_size, sizeof(*large_attr));
 			if (large_attr) {
 				(void)shim_memset(large_attr, 0, large_attr_size);
 
