@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -110,12 +110,12 @@ static int stress_shm_posix_child(
 	const size_t page_size = args->page_size;
 	struct sigaction sa;
 
-	addrs = calloc(shm_posix_objects, sizeof(*addrs));
+	addrs = (void **)calloc(shm_posix_objects, sizeof(*addrs));
 	if (!addrs) {
 		pr_fail("%s: calloc on addrs failed, out of memory\n", args->name);
 		return EXIT_NO_RESOURCE;
 	}
-	shm_names = calloc(shm_posix_objects, SHM_NAME_LEN);
+	shm_names = (char *)calloc(shm_posix_objects, SHM_NAME_LEN);
 	if (!shm_names) {
 		free(addrs);
 		pr_fail("%s: calloc on shm_names, out of memory\n", args->name);
@@ -424,7 +424,7 @@ again:
 			int status;
 			char *shm_names;
 
-			shm_names = calloc(shm_posix_objects, SHM_NAME_LEN);
+			shm_names = (char *)calloc(shm_posix_objects, SHM_NAME_LEN);
 			if (!shm_names) {
 				pr_fail("%s: calloc failed, out of memory\n", args->name);
 				(void)close(pipefds[0]);
@@ -458,8 +458,8 @@ again:
 					pr_fail("%s: zero bytes read\n", args->name);
 					break;
 				}
-				if ((msg.index < 0) ||
-				    (msg.index >= (ssize_t)shm_posix_objects)) {
+				if (UNLIKELY((msg.index < 0) ||
+					     (msg.index >= (ssize_t)shm_posix_objects))) {
 					retry = false;
 					break;
 				}
