@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -108,7 +108,7 @@ static int stress_signal(stress_args_t *args)
 		tmp = *pcounter;
 		if (LIKELY(shim_kill(pid, SIGCHLD) == 0)) {
 			while ((tmp == *pcounter) && stress_continue_flag()) {
-				shim_sched_yield();
+				(void)shim_sched_yield();
 			}
 		}
 
@@ -133,7 +133,7 @@ static int stress_signal(stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_signal_info = {
+const stressor_info_t stress_signal_info = {
 	.stressor = stress_signal,
 	.class = CLASS_SIGNAL | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
