@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -296,7 +296,7 @@ static int OPTIMIZE3 hash_put(void *handle, const uint32_t x, const uint32_t y,
 	}
 
 	/* Not found, allocate and add */
-	node = malloc(sizeof(*node));
+	node = (sparse_hash_node_t *)malloc(sizeof(*node));
 	if (!node)
 		return -1;
 	node->value = value;
@@ -589,8 +589,8 @@ static size_t rb_objmem;
  */
 static int sparse_rb_node_cmp(sparse_rb_t *n1, sparse_rb_t *n2)
 {
-	register uint64_t n1xy = n1->xy;
-	register uint64_t n2xy = n2->xy;
+	register const uint64_t n1xy = n1->xy;
+	register const uint64_t n2xy = n2->xy;
 
 	if (n1xy == n2xy)
 		return 0;
@@ -643,7 +643,7 @@ static int OPTIMIZE3 rb_put(void *handle, const uint32_t x, const uint32_t y, co
 	if (!found) {
 		sparse_rb_t *new_node;
 
-		new_node = malloc(sizeof(*new_node));
+		new_node = (sparse_rb_t *)malloc(sizeof(*new_node));
 		if (!new_node)
 			return -1;
 		new_node->value = value;
@@ -766,7 +766,7 @@ static int OPTIMIZE3 splay_put(void *handle, const uint32_t x, const uint32_t y,
 	if (!found) {
 		sparse_splay_t *new_node;
 
-		new_node = malloc(sizeof(*new_node));
+		new_node = (sparse_splay_t *)malloc(sizeof(*new_node));
 		if (!new_node)
 			return -1;
 		new_node->value = value;
@@ -878,7 +878,7 @@ static int OPTIMIZE3 list_put(void *handle, const uint32_t x, const uint32_t y,
 			goto find_x;
 		}
 		if (y_node->y > y) {
-			new_y_node = malloc(sizeof(*new_y_node));
+			new_y_node = (sparse_y_list_node_t *)malloc(sizeof(*new_y_node));
 			if (!new_y_node)
 				return -1;
 			new_y_node->y = y;
@@ -889,7 +889,7 @@ static int OPTIMIZE3 list_put(void *handle, const uint32_t x, const uint32_t y,
 		}
 	}
 
-	new_y_node = malloc(sizeof(*new_y_node));
+	new_y_node = (sparse_y_list_node_t *)malloc(sizeof(*new_y_node));
 	if (!new_y_node)
 		return -1;
 	new_y_node->y = y;
@@ -904,7 +904,7 @@ find_x:
 			return 0;
 		}
 		if (x_node->x > x) {
-			new_x_node = malloc(sizeof(*new_x_node));
+			new_x_node = (sparse_x_list_node_t *)malloc(sizeof(*new_x_node));
 			if (!new_x_node)
 				return -1;  /* Leaves new_y_node allocated */
 			new_x_node->x = x;
@@ -913,7 +913,7 @@ find_x:
 			return 0;
 		}
 	}
-	new_x_node = calloc(1, sizeof(*new_x_node));
+	new_x_node = (sparse_x_list_node_t *)calloc(1, sizeof(*new_x_node));
 	if (!new_x_node)
 		return -1;  /* Leaves new_y_node allocated */
 	new_x_node->x = x;
@@ -1107,8 +1107,8 @@ static int stress_sparse_method_test(
 
 	t1 = stress_time_now();
 	for (i = 0; stress_continue_flag() && (i < sparsematrix_items); i++) {
-		const uint32_t x = stress_mwc32modn(sparsematrix_size);
-		const uint32_t y = stress_mwc32modn(sparsematrix_size);
+		register const uint32_t x = stress_mwc32modn(sparsematrix_size);
+		register const uint32_t y = stress_mwc32modn(sparsematrix_size);
 		uint32_t gv, v = value_map(x, y);
 
 		if (v == 0)
@@ -1133,8 +1133,8 @@ static int stress_sparse_method_test(
 	stress_mwc_set_seed(w, z);
 	t1 = stress_time_now();
 	for (i = 0; stress_continue_flag() && (i < sparsematrix_items); i++) {
-		const uint32_t x = stress_mwc32modn(sparsematrix_size);
-		const uint32_t y = stress_mwc32modn(sparsematrix_size);
+		register const uint32_t x = stress_mwc32modn(sparsematrix_size);
+		register const uint32_t y = stress_mwc32modn(sparsematrix_size);
 		uint32_t gv, v = value_map(x, y);
 
 		if (v == 0)
@@ -1219,6 +1219,7 @@ static void *mmap_create(const uint64_t n, const uint32_t x, const uint32_t y)
 		MAP_ANONYMOUS | MAP_PRIVATE, -1, 0);
 	if (m.mmap == MAP_FAILED)
 		return NULL;
+	stress_set_vma_anon_name(m.mmap, m.mmap_size, "sparse-data");
 	return (void *)&m;
 }
 
@@ -1238,7 +1239,7 @@ static void mmap_destroy(void *handle, size_t *objmem)
 		return;
 
 	pages = m->mmap_size / page_size;
-	vec = calloc(pages, 1);
+	vec = (unsigned char *)calloc(pages, 1);
 	if (!vec) {
 		*objmem = m->mmap_size;
 	} else {
