@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -46,7 +46,7 @@ UNEXPECTED
 
 static const stress_help_t help[] = {
 	{ NULL,	"timerfd N",	  "start N workers producing timerfd events" },
-	{ NULL, "timerfd-fds N", "number of timerfd file descriptors to open" },
+	{ NULL, "timerfd-fds N",  "number of timerfd file descriptors to open" },
 	{ NULL,	"timerfd-freq F", "run timer(s) at F Hz, range 1 to 1000000000" },
 	{ NULL,	"timerfd-ops N",  "stop after N timerfd bogo events" },
 	{ NULL,	"timerfd-rand",	  "enable random timerfd frequency" },
@@ -161,7 +161,7 @@ static int stress_timerfd(stress_args_t *args)
 	}
 	(void)shim_unlink(file_fd_name);
 
-	timerfds = calloc((size_t)timerfd_fds, sizeof(*timerfds));
+	timerfds = (int *)calloc((size_t)timerfd_fds, sizeof(*timerfds));
 	if (!timerfds) {
 		pr_inf_skip("%s: cannot allocate %" PRIu32 " timerfd file descriptors, "
 			"skipping stressor\n", args->name, timerfd_fds);
@@ -172,7 +172,7 @@ static int stress_timerfd(stress_args_t *args)
 		timerfds[i] = -1;
 
 #if defined(USE_POLL)
-	pollfds = calloc((size_t)timerfd_fds, sizeof(*pollfds));
+	pollfds = (struct pollfd *)calloc((size_t)timerfd_fds, sizeof(*pollfds));
 	if (!pollfds) {
 		pr_inf_skip("%s: cannot allocate %" PRIu32 " pollfd file descriptors, "
 			"skipping stressor\n", args->name, timerfd_fds);
@@ -358,7 +358,7 @@ static int stress_timerfd(stress_args_t *args)
     defined(TFD_IOC_SET_TICKS)
 		/* Exercise timer tick setting ioctl */
 		{
-			unsigned long arg = 1ULL;
+			unsigned long int arg = 1ULL;
 
 			VOID_RET(int, ioctl(timerfds[0], TFD_IOC_SET_TICKS, &arg));
 		}
