@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -247,7 +247,7 @@ static int stress_yield(stress_args_t *args)
 	}
 	max_ops_per_yielder = args->max_ops / yielders;
 
-	pids = calloc(yielders, sizeof(*pids));
+	pids = (pid_t *)calloc(yielders, sizeof(*pids));
 	if (!pids) {
 		pr_inf_skip("%s: calloc failed allocating %" PRIu32
 			" pids, skipping stressor\n", args->name, yielders);
@@ -266,10 +266,7 @@ static int stress_yield(stress_args_t *args)
 		return EXIT_NO_RESOURCE;
 	}
 	stress_set_vma_anon_name(metrics, metrics_size, "metrics");
-	for (i = 0; i < yielders; i++) {
-		metrics[i].count = 0.0;
-		metrics[i].duration = 0.0;
-	}
+	stress_zero_metrics(metrics, yielders);
 
 	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
@@ -305,10 +302,10 @@ static int stress_yield(stress_args_t *args)
 
 	do {
 #if defined(__FreeBSD__)
-		VOID_RET(int, shim_sched_yield());
+		(void)shim_sched_yield();
 		stress_bogo_inc(args);
 #else
-		VOID_RET(int, shim_usleep(100000));
+		(void)shim_usleep(100000);
 #endif
 	} while (stress_continue(args));
 
