@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -104,7 +104,7 @@ static stress_zombie_t *stress_zombie_new(void)
 		zombies.free = new->next;
 		new->next = NULL;
 	} else {
-		new = calloc(1, sizeof(*new));
+		new = (stress_zombie_t *)calloc(1, sizeof(*new));
 		if (!new)
 			return NULL;
 	}
@@ -181,20 +181,6 @@ static void stress_zombie_free(void)
 	}
 }
 
-/*
- *  stress_set_zombie_max()
- *	set maximum number of zombies allowed
- */
-static int stress_set_zombie_max(const char *opt)
-{
-	uint32_t zombie_max;
-
-	zombie_max = stress_get_uint32(opt);
-	stress_check_range("zombie-max", (uint64_t)zombie_max,
-		MIN_ZOMBIES, MAX_ZOMBIES);
-	return stress_set_setting("zombie-max", TYPE_ID_INT32, &zombie_max);
-}
-
 /*
  *  stress_zombie()
  *	stress by zombieing and exiting
@@ -211,6 +197,8 @@ static int stress_zombie(stress_args_t *args)
 			zombie_max = MIN_ZOMBIES;
 	}
 
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
@@ -253,7 +241,7 @@ static int stress_zombie(stress_args_t *args)
 	} while (stress_continue(args));
 
 	stress_metrics_set(args, 0, "created zombies per stressor",
-		(double)max_zombies, STRESS_HARMONIC_MEAN);
+		(double)max_zombies, STRESS_METRIC_HARMONIC_MEAN);
 
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
@@ -267,15 +255,15 @@ static int stress_zombie(stress_args_t *args)
 	return EXIT_SUCCESS;
 }
 
-static const stress_opt_set_func_t opt_set_funcs[] = {
-	{ OPT_zombie_max,	stress_set_zombie_max },
-	{ 0,			NULL }
+static const stress_opt_t opts[] = {
+	{ OPT_zombie_max, "zombie-max", TYPE_ID_INT32, MIN_ZOMBIES, MAX_ZOMBIES, NULL },
+	END_OPT,
 };
 
-stressor_info_t stress_zombie_info = {
+const stressor_info_t stress_zombie_info = {
 	.stressor = stress_zombie,
 	.class = CLASS_SCHEDULER | CLASS_OS,
-	.opt_set_funcs = opt_set_funcs,
+	.opts = opts,
 	.verify = VERIFY_OPTIONAL,
 	.help = help
 };
